@@ -214,24 +214,40 @@ totem_time_to_string (gint64 msecs)
 		/* Translators: This is a time format, like "9:05:02" for 9
 		 * hours, 5 minutes, and 2 seconds. You may change ":" to
 		 * the separator that your locale uses or use "%Id" instead
-		 * of "%d" if your locale uses localized digits. Do not
-		 * translate the "long time format|" part. Remove it from
-		 * the translation.
+		 * of "%d" if your locale uses localized digits.
 		 */
-		return g_strdup_printf (Q_("long time format|%d:%02d:%02d"), hour, min, sec);
-	} else {
-		/* minutes:seconds */
-		/* Translators: This is a time format, like "5:02" for 5
-		 * minutes and 2 seconds. You may change ":" to the
-		 * separator that your locale uses or use "%Id" instead of
-		 * "%d" if your locale uses localized digits. Do not
-		 * translate the "short time format|" part. Remove it from
-		 * the translation.
-		 */
-		return g_strdup_printf (Q_("short time format|%d:%02d"), min, sec);
+		return g_strdup_printf (C_("long time format", "%d:%02d:%02d"), hour, min, sec);
 	}
 
-	return NULL;
+	/* minutes:seconds */
+	/* Translators: This is a time format, like "5:02" for 5
+	 * minutes and 2 seconds. You may change ":" to the
+	 * separator that your locale uses or use "%Id" instead of
+	 * "%d" if your locale uses localized digits.
+	 */
+	return g_strdup_printf (C_("short time format", "%d:%02d"), min, sec);
+}
+
+gint64
+totem_string_to_time (const char *time_string)
+{
+	int sec, min, hour, args;
+
+	args = sscanf (time_string, C_("long time format", "%d:%02d:%02d"), &hour, &min, &sec);
+
+	if (args == 3) {
+		/* Parsed all three arguments successfully */
+		return (hour * (60 * 60) + min * 60 + sec) * 1000;
+	} else if (args == 2) {
+		/* Only parsed the first two arguments; treat hour and min as min and sec, respectively */
+		return (hour * 60 + min) * 1000;
+	} else if (args == 1) {
+		/* Only parsed the first argument; treat hour as sec */
+		return hour * 1000;
+	} else {
+		/* Error! */
+		return -1;
+	}
 }
 
 char *
