@@ -1,13 +1,16 @@
 import totem
-import gobject, gtk, gio
+import gobject, gtk, gio, gconf
 gobject.threads_init()
 import xmlrpclib
 import threading
 import xdg.BaseDirectory
 from os import sep
+import gettext
 
 from hash import hashFile
 
+D_ = gettext.dgettext
+
 USER_AGENT = 'Totem'
 OK200 = '200 OK'
 TOTEM_REMOTE_COMMAND_REPLACE = 14
@@ -22,17 +25,113 @@ SUBTITLES_EXT = [
         "ass",
 ]
 
-LANGUAGES_STR = [(_('Catalan'), 'cat'),
-                 (_('English'), 'eng'),
-                 (_('French'),  'fre'),
-                 (_('German'),  'ger'),
-                 (_('Spanish'), 'spa'),]
+# Map of the language codes used by opensubtitles.org's API to their human-readable name
+LANGUAGES_STR = [(D_('iso_639_3', 'Albanian'), 'sq'),
+		 (D_('iso_639_3', 'Arabic'), 'ar'),
+		 (D_('iso_639_3', 'Armenian'), 'hy'),
+		 (D_('iso_639_3', 'Neo-Aramaic, Assyrian'), 'ay'),
+		 (D_('iso_639_3', 'Bosnian'), 'bs'),
+		 (_('Brasilian Portuguese'), 'pb'),
+		 (D_('iso_639_3', 'Bulgarian'), 'bg'),
+		 (D_('iso_639_3', 'Catalan'), 'ca'),
+		 (D_('iso_639_3', 'Chinese'), 'zh'),
+		 (D_('iso_639_3', 'Croatian'), 'hr'),
+		 (D_('iso_639_3', 'Czech'), 'cs'),
+		 (D_('iso_639_3', 'Danish'), 'da'),
+		 (D_('iso_639_3', 'Dutch'), 'nl'),
+		 (D_('iso_639_3', 'English'), 'en'),
+		 (D_('iso_639_3', 'Esperanto'), 'eo'),
+		 (D_('iso_639_3', 'Estonian'), 'et'),
+		 (D_('iso_639_3', 'Finnish'), 'fi'),
+		 (D_('iso_639_3', 'French'), 'fr'),
+		 (D_('iso_639_3', 'Galician'), 'gl'),
+		 (D_('iso_639_3', 'Georgian'), 'ka'),
+		 (D_('iso_639_3', 'German'), 'de'),
+		 (D_('iso_639_3', 'Greek, Modern (1453-)'), 'el'),
+		 (D_('iso_639_3', 'Hebrew'), 'he'),
+		 (D_('iso_639_3', 'Hindi'), 'hi'),
+		 (D_('iso_639_3', 'Hungarian'), 'hu'),
+		 (D_('iso_639_3', 'Icelandic'), 'is'),
+		 (D_('iso_639_3', 'Indonesian'), 'id'),
+		 (D_('iso_639_3', 'Italian'), 'it'),
+		 (D_('iso_639_3', 'Japanese'), 'ja'),
+		 (D_('iso_639_3', 'Kazakh'), 'kk'),
+		 (D_('iso_639_3', 'Korean'), 'ko'),
+		 (D_('iso_639_3', 'Latvian'), 'lv'),
+		 (D_('iso_639_3', 'Lithuanian'), 'lt'),
+		 (D_('iso_639_3', 'Luxembourgish'), 'lb'),
+		 (D_('iso_639_3', 'Macedonian'), 'mk'),
+		 (D_('iso_639_3', 'Malay (macrolanguage)'), 'ms'),
+		 (D_('iso_639_3', 'Norwegian'), 'no'),
+		 (D_('iso_639_3', 'Occitan (post 1500)'), 'oc'),
+		 (D_('iso_639_3', 'Persian'), 'fa'),
+		 (D_('iso_639_3', 'Polish'), 'pl'),
+		 (D_('iso_639_3', 'Portuguese'), 'pt'),
+		 (D_('iso_639_3', 'Romanian'), 'ro'),
+		 (D_('iso_639_3', 'Russian'), 'ru'),
+		 (D_('iso_639_3', 'Serbian'), 'sr'),
+		 (D_('iso_639_3', 'Slovak'), 'sk'),
+		 (D_('iso_639_3', 'Slovenian'), 'sl'),
+		 (D_('iso_639_3', 'Spanish'), 'es'),
+		 (D_('iso_639_3', 'Swedish'), 'sv'),
+		 (D_('iso_639_3', 'Thai'), 'th'),
+		 (D_('iso_639_3', 'Turkish'), 'tr'),
+		 (D_('iso_639_3', 'Ukrainian'), 'uk'),
+		 (D_('iso_639_3', 'Vietnamese'), 'vi'),]
 
-LANGUAGES =     {'ca':'cat',
-                 'de':'ger',
-                 'en':'eng',
-                 'es':'spa',
-                 'fr':'fre'}
+# Map of ISO 639-1 language codes to the codes used by opensubtitles.org's API
+LANGUAGES =     {'sq':'alb',
+		 'ar':'ara',
+		 'hy':'arm',
+		 'ay':'ass',
+		 'bs':'bos',
+		 'pb':'pob',
+		 'bg':'bul',
+		 'ca':'cat',
+		 'zh':'chi',
+		 'hr':'hrv',
+		 'cs':'cze',
+		 'da':'dan',
+		 'nl':'dut',
+		 'en':'eng',
+		 'eo':'epo',
+		 'et':'est',
+		 'fi':'fin',
+		 'fr':'fre',
+		 'gl':'glg',
+		 'ka':'geo',
+		 'de':'ger',
+		 'el':'ell',
+		 'he':'heb',
+		 'hi':'hin',
+		 'hu':'hun',
+		 'is':'ice',
+		 'id':'ind',
+		 'it':'ita',
+		 'ja':'jpn',
+		 'kk':'kaz',
+		 'ko':'kor',
+		 'lv':'lav',
+		 'lt':'lit',
+		 'lb':'ltz',
+		 'mk':'mac',
+		 'ms':'may',
+		 'no':'nor',
+		 'oc':'oci',
+		 'fa':'per',
+		 'pl':'pol',
+		 'pt':'por',
+		 'ro':'rum',
+		 'ru':'rus',
+		 'sr':'scc',
+		 'sk':'slo',
+		 'sl':'slv',
+		 'es':'spa',
+		 'sv':'swe',
+		 'th':'tha',
+		 'tr':'tur',
+		 'uk':'ukr',
+		 'vi':'vie',}
 
 class SearchThread(threading.Thread):
     """
@@ -191,6 +290,9 @@ class OpenSubtitles(totem.Plugin):
     def __init__(self):
         totem.Plugin.__init__(self)
         self.dialog = None
+        self.gconf_client = gconf.client_get_default()
+        self.GCONF_BASE_DIR = "/apps/totem/plugins/opensubtitles/"
+        self.GCONF_LANGUAGE = "language"
 
     # totem.Plugin methods
 
@@ -244,14 +346,18 @@ class OpenSubtitles(totem.Plugin):
 
         # Set up and populate the languages combobox
         renderer = gtk.CellRendererText()
-        combobox.set_model(languages)
+        sorted_languages = gtk.TreeModelSort(languages)
+        sorted_languages.set_sort_column_id(0, gtk.SORT_ASCENDING)
+        combobox.set_model(sorted_languages)
         combobox.pack_start(renderer, True)
         combobox.add_attribute(renderer, 'text', 0)
 
+        self.model.lang = self.gconf_get_str (self.GCONF_BASE_DIR + self.GCONF_LANGUAGE, self.model.lang)
         for lang in LANGUAGES_STR:
             it = languages.append(lang)
-            if lang[1] == self.model.lang:
-                combobox.set_active_iter(it)
+            if LANGUAGES[lang[1]] == self.model.lang:
+                parentit = sorted_languages.convert_child_iter_to_iter (None, it)
+                combobox.set_active_iter(parentit)
 
         # Set up the results treeview 
         renderer = gtk.CellRendererText()
@@ -461,12 +567,14 @@ class OpenSubtitles(totem.Plugin):
 	self.progress.set_fraction(0.0)
 	self.find_button.set_sensitive(True)
         self.apply_button.set_sensitive(False)
+        self.treeview.set_sensitive(True)
         return False
 
     def os_download_and_apply(self):
         self.apply_button.set_sensitive(False)
         self.find_button.set_sensitive(False)
         self.action.set_sensitive(False)
+        self.treeview.set_sensitive(False)
         self.os_save_selected_subtitle()
 
     # Callbacks
@@ -509,7 +617,9 @@ class OpenSubtitles(totem.Plugin):
 
     def on_combobox__changed(self, combobox):
         iter = combobox.get_active_iter()
-        self.model.lang = combobox.get_model().get_value(iter, 1)
+        self.model.lang = LANGUAGES[combobox.get_model().get_value(iter, 1)]
+        self.gconf_set_str(self.GCONF_BASE_DIR + self.GCONF_LANGUAGE,
+                           self.model.lang)
 
     def on_close_clicked(self, data):
         self.dialog.destroy()
@@ -525,3 +635,15 @@ class OpenSubtitles(totem.Plugin):
         self.model.hash , self.model.size = hashFile(self.filename)
 
         self.os_get_results()
+
+    def gconf_get_str(self, key, default = ""):
+        val = self.gconf_client.get(key)
+        
+        if val is not None and val.type == gconf.VALUE_STRING:
+            return val.get_string()
+        else:
+            return default
+
+    def gconf_set_str(self, key, val):
+        self.gconf_client.set_string(key, val)
+
