@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301  USA.
 
    Author: Bastien Nocera <hadess@hadess.net>
  */
@@ -43,7 +43,6 @@ void eject_action_callback (GtkAction *action, Totem *totem);
 void properties_action_callback (GtkAction *action, Totem *totem);
 void play_action_callback (GtkAction *action, Totem *totem);
 void quit_action_callback (GtkAction *action, Totem *totem);
-void take_screenshot_action_callback (GtkAction *action, Totem *totem);
 void preferences_action_callback (GtkAction *action, Totem *totem);
 void fullscreen_action_callback (GtkAction *action, Totem *totem);
 void zoom_1_2_action_callback (GtkAction *action, Totem *totem);
@@ -73,6 +72,7 @@ void deinterlace_action_callback (GtkToggleAction *action, Totem *totem);
 void show_controls_action_callback (GtkToggleAction *action, Totem *totem);
 void show_sidebar_action_callback (GtkToggleAction *action, Totem *totem);
 void aspect_ratio_changed_callback (GtkRadioAction *action, GtkRadioAction *current, Totem *totem);
+void select_subtitle_action_callback (GtkAction *action, Totem *totem);
 void clear_playlist_action_callback (GtkAction *action, Totem *totem);
 
 /* Helper function to escape underscores in labels
@@ -276,13 +276,14 @@ languages_changed_callback (GtkRadioAction *action, GtkRadioAction *current,
 
 static GtkAction *
 add_lang_action (Totem *totem, GtkActionGroup *action_group, guint ui_id,
-		const char *path, const char *prefix, const char *lang, 
+		const char **paths, const char *prefix, const char *lang, 
 		int lang_id, int index, GSList **group)
 {
 	const char *full_lang;
 	char *label;
 	char *name;
 	GtkAction *action;
+	guint i;
 
 	full_lang = totem_lang_get_full (lang);
 
@@ -298,7 +299,6 @@ add_lang_action (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 		label = escape_label_for_menu (full_lang ? full_lang : lang);
 	}
 
-        /* FIXMEchpe i18n! */
 	name = g_strdup_printf ("%s-%d", prefix, lang_id);
 
 	action = g_object_new (GTK_TYPE_RADIO_ACTION,
@@ -312,8 +312,10 @@ add_lang_action (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 	*group = gtk_radio_action_get_group (GTK_RADIO_ACTION (action));
 	gtk_action_group_add_action (action_group, action);
 	g_object_unref (action);
-	gtk_ui_manager_add_ui (totem->ui_manager, ui_id,
-			       path, name, name, GTK_UI_MANAGER_MENUITEM, FALSE);
+	for (i = 0; paths[i] != NULL; i++) {
+		gtk_ui_manager_add_ui (totem->ui_manager, ui_id,
+				       paths[i], name, name, GTK_UI_MANAGER_MENUITEM, FALSE);
+	}
 	g_free (name);
 
 	return action;
@@ -321,7 +323,7 @@ add_lang_action (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 
 static GtkAction *
 create_lang_actions (Totem *totem, GtkActionGroup *action_group, guint ui_id,
-		const char *path, const char *prefix, GList *list,
+		const char **paths, const char *prefix, GList *list,
 		gboolean is_lang)
 {
 	GtkAction *action = NULL;
@@ -332,11 +334,11 @@ create_lang_actions (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 	char *action_data;
 
 	if (is_lang == FALSE) {
-		add_lang_action (totem, action_group, ui_id, path, prefix,
+		add_lang_action (totem, action_group, ui_id, paths, prefix,
 				_("None"), -2, 0, &group);
 	}
 
-	action = add_lang_action (totem, action_group, ui_id, path, prefix,
+	action = add_lang_action (totem, action_group, ui_id, paths, prefix,
 			_("Auto"), -1, 0, &group);
 
 	i = 0;
@@ -357,7 +359,7 @@ create_lang_actions (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 			g_hash_table_replace (lookup, l->data, GINT_TO_POINTER (num + 1));
 		}
 
-		add_lang_action (totem, action_group, ui_id, path, prefix,
+		add_lang_action (totem, action_group, ui_id, paths, prefix,
 				 action_data, i, num + 1, &group);
 		g_free (action_data);
  		i++;
@@ -400,6 +402,7 @@ static void
 totem_languages_update (Totem *totem, GList *list)
 {
 	GtkAction *action;
+	const char *paths[3] = { "/tmw-menubar/sound/languages/placeholder", "/totem-main-popup/popup-languages/placeholder", NULL };
 	int current;
 
 	/* Remove old UI */
@@ -416,11 +419,10 @@ totem_languages_update (Totem *totem, GList *list)
 	gtk_ui_manager_insert_action_group (totem->ui_manager,
 			totem->languages_action_group, -1);
 
-	if (list != NULL)
-	{
+	if (list != NULL) {
 		action = create_lang_actions (totem, totem->languages_action_group,
 				totem->languages_ui_id,
-				"/tmw-menubar/sound/languages/placeholder",
+				paths,
 			       	"languages", list, TRUE);
 		gtk_ui_manager_ensure_update (totem->ui_manager);
 
@@ -440,6 +442,7 @@ totem_subtitles_update (Totem *totem, GList *list)
 {
 	GtkAction *action;
 	int current;
+	const char *paths[3] = { "/tmw-menubar/view/subtitles/placeholder", "/totem-main-popup/popup-subtitles/placeholder", NULL };
 
 	/* Remove old UI */
 	gtk_ui_manager_remove_ui (totem->ui_manager, totem->subtitles_ui_id);
@@ -460,7 +463,7 @@ totem_subtitles_update (Totem *totem, GList *list)
 	{
 		action = create_lang_actions (totem, totem->subtitles_action_group,
 				totem->subtitles_ui_id,
-				"/tmw-menubar/view/subtitles/placeholder",
+				paths,
 			       	"subtitles", list, FALSE);
 		gtk_ui_manager_ensure_update (totem->ui_manager);
 
@@ -550,7 +553,7 @@ on_recent_file_item_activated (GtkAction *action,
 	recent_info = g_object_get_data (G_OBJECT (action), "recent-info");
 	uri = gtk_recent_info_get_uri (recent_info);
 
-	totem_add_to_playlist_and_play (totem, uri, NULL, TRUE);
+	totem_add_to_playlist_and_play (totem, uri, NULL, FALSE);
 }
 
 static gint
@@ -580,7 +583,7 @@ totem_compare_recent_items (GtkRecentInfo *a, GtkRecentInfo *b)
 static void
 totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *totem)
 {
-        GList *items, *l;
+        GList *items, *totem_items, *l;
         guint n_items = 0;
 
         if (totem->recent_ui_id != 0) {
@@ -602,10 +605,26 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
 
         totem->recent_ui_id = gtk_ui_manager_new_merge_id (totem->ui_manager);
         items = gtk_recent_manager_get_items (recent_manager);
-        items = g_list_sort (items, (GCompareFunc) totem_compare_recent_items);
 
+	/* Remove the non-Totem items */
+	totem_items = NULL;
         for (l = items; l && l->data; l = l->next) {
                 GtkRecentInfo *info;
+
+                info = (GtkRecentInfo *) l->data;
+
+                if (gtk_recent_info_has_group (info, "Totem")) {
+                	gtk_recent_info_ref (info);
+                	totem_items = g_list_prepend (totem_items, info);
+		}
+	}
+	g_list_foreach (items, (GFunc) gtk_recent_info_unref, NULL);
+        g_list_free (items);
+
+        totem_items = g_list_sort (totem_items, (GCompareFunc) totem_compare_recent_items);
+
+        for (l = totem_items; l && l->data; l = l->next) {
+                GtkRecentInfo *info;
                 GtkAction     *action;
                 char           action_name[32];
                 const char    *display_name;
@@ -647,8 +666,8 @@ totem_recent_manager_changed_callback (GtkRecentManager *recent_manager, Totem *
                         break;
         }
 
-        g_list_foreach (items, (GFunc) gtk_recent_info_unref, NULL);
-        g_list_free (items);
+        g_list_foreach (totem_items, (GFunc) gtk_recent_info_unref, NULL);
+        g_list_free (totem_items);
 }
 
 void
@@ -666,45 +685,42 @@ totem_setup_recent (Totem *totem)
 }
 
 void
-totem_action_add_recent (Totem *totem, const char *filename)
+totem_action_add_recent (Totem *totem, const char *uri)
 {
 	GtkRecentData data;
 	char *groups[] = { NULL, NULL };
+	GFile *file;
+	GFileInfo *file_info;
 
 	memset (&data, 0, sizeof (data));
 
-	data.mime_type = gnome_vfs_get_mime_type (filename);
-	if (data.mime_type == NULL) {
-		/* No mime-type means warnings, and it breaks when adding
-		 * non-gnome-vfs supported URI schemes */
-		return;
-	}
-	data.display_name = NULL;
+	file = g_file_new_for_uri (uri);
+	file_info = g_file_query_info (file,
+				       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE "," G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+				       G_FILE_QUERY_INFO_NONE, NULL, NULL);
 
-	if (strstr (filename, "file:///") == NULL) {
-		/* It's a URI/stream */
+	/* Probably an unsupported URI scheme */
+	if (file_info == NULL) {
+		data.display_name = NULL;
+		/* Bogus mime-type, we just want it added */
+		data.mime_type = g_strdup ("video/x-totem-stream");
 		groups[0] = "TotemStreams";
+		g_message ("no file info");
 	} else {
-		char *display;
-
-		/* Local files with no mime-type probably don't exist */
-		if (data.mime_type == NULL)
-			return;
-
-		/* It's a local file */
-		display = g_filename_from_uri (filename, NULL, NULL);
-		if (display) {
-			data.display_name = g_filename_display_basename (display);
-			g_free (display);
-		}
+		data.mime_type = g_strdup (g_file_info_get_content_type (file_info));
+		data.display_name = g_strdup (g_file_info_get_display_name (file_info));
+		g_object_unref (file_info);
 		groups[0] = "Totem";
 	}
+	g_object_unref (file);
 
 	data.app_name = g_strdup (g_get_application_name ());
 	data.app_exec = g_strjoin (" ", g_get_prgname (), "%u", NULL);
 	data.groups = groups;
-	gtk_recent_manager_add_full (totem->recent_manager,
-				     filename, &data);
+	if (gtk_recent_manager_add_full (totem->recent_manager,
+				     uri, &data) == FALSE) {
+		g_message ("Couldn't add recent file for '%s'", uri);
+	}
 
 	g_free (data.display_name);
 	g_free (data.mime_type);
@@ -723,110 +739,191 @@ on_play_disc_activate (GtkAction *action, Totem *totem)
 	totem_action_play_media_device (totem, device_path);
 }
 
-/* A GnomeVFSDrive and GnomeVFSVolume share many similar methods, but do not
-   share a base class other than GObject. */
-static char *
-fake_gnome_vfs_device_get_something (GObject *device,
-		char *(*volume_function) (GnomeVFSVolume *),
-		char *(*drive_function) (GnomeVFSDrive *)) {
-        if (GNOME_IS_VFS_VOLUME (device)) {
-                return (*volume_function) (GNOME_VFS_VOLUME (device));
-        } else if (GNOME_IS_VFS_DRIVE (device)) {
-                return (*drive_function) (GNOME_VFS_DRIVE (device));
-        } else {
-                g_warning ("neither a GnomeVFSVolume or a GnomeVFSDrive");
-                return NULL;
-        }
-}
-
-static char *
-my_gnome_vfs_volume_get_mount_path (GnomeVFSVolume *volume)
+/* Play DVB menu items */
+static void
+on_play_dvb_activate (GtkAction *action, Totem *totem)
 {
-	char *uri, *path;
+	int adapter;
+	char *str;
 
-	uri = gnome_vfs_volume_get_activation_uri (volume);
-	path = g_filename_from_uri (uri, NULL, NULL);
-	g_free (uri);
-
-	if (path == NULL)
-		return gnome_vfs_volume_get_device_path (volume);
-	return path;
+	adapter = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (action), "adapter"));
+	str = g_strdup_printf ("%d", adapter);
+	totem_action_play_media (totem, MEDIA_TYPE_DVB, str);
+	g_free (str);
 }
 
 static void
-add_device_to_menu (GObject *device, guint position, Totem *totem)
+add_drive_to_menu (GDrive *drive, guint position, Totem *totem)
 {
-	char *name, *escaped_name, *icon_name, *device_path;
-	char *label, *activation_uri;
-	GtkAction *action;
-	gboolean disabled = FALSE;
+	GtkIconTheme *theme;
+	GList *volumes, *i;
 
-	/* Add devices with blank CDs and audio CDs in them, but disable them */
-	activation_uri = fake_gnome_vfs_device_get_something (device,
-		&gnome_vfs_volume_get_activation_uri,
-		&gnome_vfs_drive_get_activation_uri);
-	if (activation_uri != NULL) {
-		if (g_str_has_prefix (activation_uri, "burn://") != FALSE || g_str_has_prefix (activation_uri, "cdda://") != FALSE) {
+	theme = gtk_icon_theme_get_default ();
+
+	/* Repeat for all the drive's volumes */
+	volumes = g_drive_get_volumes (drive);
+
+	for (i = volumes; i != NULL; i = i->next) {
+		char *name, *escaped_name, *label;
+		GtkAction *action;
+		gboolean disabled;
+		GIcon *icon;
+		const char * const *icon_names;
+		const char *icon_name;
+		guint j;
+		char *device_path;
+
+		disabled = FALSE;
+
+		/* Add devices with blank CDs and audio CDs in them, but disable them */
+		device_path = g_volume_get_identifier (i->data, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+		if (device_path == NULL)
+			continue;
+
+		/* Check whether we have a media... */
+		if (g_drive_has_media (drive) == FALSE) {
 			disabled = TRUE;
+		} else {
+			/* ... Or an audio CD or a blank media */
+			GMount *mount;
+			GFile *root;
+
+			mount = g_volume_get_mount (i->data);
+			if (mount != NULL) {
+				root = g_mount_get_root (mount);
+				g_object_unref (mount);
+
+				if (g_file_has_uri_scheme (root, "burn") != FALSE || g_file_has_uri_scheme (root, "cdda") != FALSE)
+					disabled = TRUE;
+				g_object_unref (root);
+			}
 		}
-		g_free (activation_uri);
-	} else {
-		if (GNOME_IS_VFS_DRIVE (device)) {
-			device_path = gnome_vfs_drive_get_device_path
-				(GNOME_VFS_DRIVE (device));
-			disabled = !totem_cd_has_medium (device_path);
+
+		/* Work out an icon to display */
+		icon = g_volume_get_icon (i->data);
+		icon_name = NULL;
+		icon_names = g_themed_icon_get_names (G_THEMED_ICON (icon));
+
+		for (j = 0; icon_names[j] != NULL; j++) {
+			icon_name = icon_names[j];
+			if (gtk_icon_theme_has_icon (theme, icon_name) != FALSE)
+				break;
+		}
+
+		/* Get the volume's pretty name for the menu label */
+		name = g_volume_get_name (i->data);
+		g_strstrip (name);
+		escaped_name = escape_label_for_menu (name);
+		g_free (name);
+		label = g_strdup_printf (_("Play Disc '%s'"), escaped_name);
+		g_free (escaped_name);
+
+		name = g_strdup_printf (_("device%d"), position);
+
+		action = gtk_action_new (name, label, NULL, NULL);
+		g_object_set (G_OBJECT (action),
+			      "icon-name", icon_name,
+			      "sensitive", !disabled, NULL);
+		gtk_action_group_add_action (totem->devices_action_group, action);
+		g_object_unref (action);
+
+		gtk_ui_manager_add_ui (totem->ui_manager, totem->devices_ui_id,
+			"/tmw-menubar/movie/devices-placeholder", name, name,
+			GTK_UI_MANAGER_MENUITEM, FALSE);
+
+		g_free (name);
+		g_free (label);
+		g_object_unref (icon);
+
+		if (disabled != FALSE) {
 			g_free (device_path);
+			return;
 		}
+
+		g_object_set_data_full (G_OBJECT (action),
+					"device_path", device_path,
+					(GDestroyNotify) g_free);
+
+		g_signal_connect (G_OBJECT (action), "activate",
+				  G_CALLBACK (on_play_disc_activate), totem);
 	}
 
-	name = fake_gnome_vfs_device_get_something (device,
-		&gnome_vfs_volume_get_display_name,
-		&gnome_vfs_drive_get_display_name);
-	icon_name = fake_gnome_vfs_device_get_something (device,
-		&gnome_vfs_volume_get_icon, &gnome_vfs_drive_get_icon);
-	device_path = fake_gnome_vfs_device_get_something (device,
-		&my_gnome_vfs_volume_get_mount_path,
-		&gnome_vfs_drive_get_device_path);
+	g_list_free (volumes);
+}
 
-	g_strstrip (name);
-	escaped_name = escape_label_for_menu (name);
-	g_free (name);
-	label = g_strdup_printf (_("Play Disc '%s'"), escaped_name);
-	g_free (escaped_name);
+static void
+update_drive_menu_items (GtkMenuItem *movie_menuitem, Totem *totem)
+{
+	GList *drives, *i;
+	guint position;
 
-	name = g_strdup_printf (_("device%d"), position);
-	action = gtk_action_new (name, label, NULL, NULL);
-	g_object_set (G_OBJECT (action), "icon-name", icon_name,
-		      "sensitive", !disabled, NULL);
-	gtk_action_group_add_action (totem->devices_action_group, action);
-	g_object_unref (action);
-	gtk_ui_manager_add_ui (totem->ui_manager, totem->devices_ui_id,
-		"/tmw-menubar/movie/devices-placeholder", name, name,
-		GTK_UI_MANAGER_MENUITEM, FALSE);
-	g_free (name);
-	g_free (label);
-	g_free (icon_name);
+	/* Add any suitable devices to the menu */
+	position = 0;
 
-	if (disabled != FALSE)
-		return;
+	drives = g_volume_monitor_get_connected_drives (totem->monitor);
+	for (i = drives; i != NULL; i = i->next) {
+		/* FIXME: We used to explicitly check whether it was a CD/DVD drive
+		 * Use:
+		 * udi = g_volume_get_identifier (i->data, G_VOLUME_IDENTIFIER_KIND_HAL_UDI); */
+		if (g_drive_can_eject (i->data) == FALSE)
+			continue;
 
-	g_object_set_data_full (G_OBJECT (action),
-				"device_path", device_path,
-				(GDestroyNotify) g_free);
+		position++;
+		add_drive_to_menu (i->data, position, totem);
+	}
+	g_list_free (drives);
 
-	g_signal_connect (G_OBJECT (action), "activate",
-			G_CALLBACK (on_play_disc_activate), totem);
+	totem->drives_changed = FALSE;
+}
+
+static void
+update_dvb_menu_items (GtkMenuItem *movie_menuitem, Totem *totem)
+{
+	guint i;
+
+	for (i = 0 ; i < 8 ; i++) {
+		char *devicenode;
+
+		devicenode = g_strdup_printf("/dev/dvb/adapter%d/frontend0", i);
+
+		if (g_file_test (devicenode, G_FILE_TEST_EXISTS) != FALSE) {
+			char* label, *name, *adapter_name;
+			GtkAction* action;
+
+			/* translators: the index of the adapter
+			 * DVB Adapter 1 */
+			adapter_name = g_strdup_printf (_("DVB Adapter %u"), i);
+			/* translators:
+			 * Watch TV on 'DVB Adapter 1'
+			 * or
+			 * Watch TV on 'Hauppauge Nova-T Stick' */
+			label = g_strdup_printf (_("Watch TV on \'%s\'"), adapter_name);
+			g_free (adapter_name);
+			name = g_strdup_printf ("dvbdevice%d", i);
+			action = gtk_action_new (name, label, NULL, NULL);
+
+			g_object_set (G_OBJECT(action), "icon-name", "totem-tv", "sensitive", TRUE, NULL);
+			gtk_action_group_add_action (totem->devices_action_group, action);
+			g_object_unref (action);
+			gtk_ui_manager_add_ui (totem->ui_manager, totem->devices_ui_id,
+					       "/tmw-menubar/movie/devices-placeholder", name, name,
+					       GTK_UI_MANAGER_MENUITEM, FALSE);
+			g_object_set_data_full (G_OBJECT (action),
+						"adapter", GINT_TO_POINTER (i), NULL);
+			g_signal_connect (G_OBJECT (action), "activate",
+					  G_CALLBACK (on_play_dvb_activate), totem);
+		}
+		g_free (devicenode);
+	}
 }
 
 static void
 on_movie_menu_select (GtkMenuItem *movie_menuitem, Totem *totem)
 {
-	GList *devices, *volumes, *drives, *i;
-	guint position;
-
-	if (totem->drives_changed == FALSE)
+	//FIXME we should check whether there's new DVB items
+/*	if (totem->drives_changed == FALSE)
 		return;
-
+*/
 	/* Remove old UI */
 	gtk_ui_manager_remove_ui (totem->ui_manager, totem->devices_ui_id);
 	gtk_ui_manager_ensure_update (totem->ui_manager);
@@ -841,51 +938,19 @@ on_movie_menu_select (GtkMenuItem *movie_menuitem, Totem *totem)
 	gtk_ui_manager_insert_action_group (totem->ui_manager,
 			totem->devices_action_group, -1);
 
-	/* Create a list of suitable devices */
-	devices = NULL;
+	update_drive_menu_items (movie_menuitem, totem);
 
-	volumes = gnome_vfs_volume_monitor_get_mounted_volumes
-		(totem->monitor);
-	for (i = volumes; i != NULL; i = i->next) {
-		if (gnome_vfs_volume_get_device_type (i->data) != GNOME_VFS_DEVICE_TYPE_CDROM)
-			continue;
+	/* Check for DVB */
+	/* FIXME we should only update if we have an updated as per HAL */
+	update_dvb_menu_items (movie_menuitem, totem);
 
-		gnome_vfs_volume_ref (i->data);
-		devices = g_list_append (devices, i->data);
-	}
-	gnome_vfs_drive_volume_list_free (volumes);
-
-	drives = gnome_vfs_volume_monitor_get_connected_drives (totem->monitor);
-	for (i = drives; i != NULL; i = i->next) {
-		if (gnome_vfs_drive_get_device_type (i->data) != GNOME_VFS_DEVICE_TYPE_CDROM)
-			continue;
-		else if (gnome_vfs_drive_is_mounted (i->data))
-			continue;
-
-		gnome_vfs_volume_ref (i->data);
-		devices = g_list_append (devices, i->data);
-	}
-	gnome_vfs_drive_volume_list_free (drives);
-
-	/* Add the devices to the menu */
-	position = 0;
-
-	for (i = devices; i != NULL; i = i->next) {
-		position++;
-		add_device_to_menu (i->data, position, totem);
-	}
 	gtk_ui_manager_ensure_update (totem->ui_manager);
-
-	g_list_foreach (devices, (GFunc) g_object_unref, NULL);
-	g_list_free (devices);
-
-	totem->drives_changed = FALSE;
 }
 
 static void
-on_gnome_vfs_monitor_event (GnomeVFSVolumeMonitor *monitor,
-		GnomeVFSDrive *drive,
-		Totem *totem)
+on_g_volume_monitor_event (GVolumeMonitor *monitor,
+			   gpointer *device,
+			   Totem *totem)
 {
 	totem->drives_changed = TRUE;
 }
@@ -900,17 +965,17 @@ totem_setup_play_disc (Totem *totem)
 			G_CALLBACK (on_movie_menu_select), totem);
 
 	g_signal_connect (G_OBJECT (totem->monitor),
-			"drive-connected",
-			G_CALLBACK (on_gnome_vfs_monitor_event), totem);
+			"volume-added",
+			G_CALLBACK (on_g_volume_monitor_event), totem);
 	g_signal_connect (G_OBJECT (totem->monitor),
-			"drive-disconnected",
-			G_CALLBACK (on_gnome_vfs_monitor_event), totem);
+			"volume-removed",
+			G_CALLBACK (on_g_volume_monitor_event), totem);
 	g_signal_connect (G_OBJECT (totem->monitor),
-			"volume-mounted",
-			G_CALLBACK (on_gnome_vfs_monitor_event), totem);
+			"mount-added",
+			G_CALLBACK (on_g_volume_monitor_event), totem);
 	g_signal_connect (G_OBJECT (totem->monitor),
-			"volume-unmounted",
-			G_CALLBACK (on_gnome_vfs_monitor_event), totem);
+			"mount-removed",
+			G_CALLBACK (on_g_volume_monitor_event), totem);
 
 	totem->drives_changed = TRUE;
 }
@@ -945,18 +1010,12 @@ play_action_callback (GtkAction *action, Totem *totem)
 	totem_action_play_pause (totem);
 }
 
-void
+G_GNUC_NORETURN void
 quit_action_callback (GtkAction *action, Totem *totem)
 {
 	totem_action_exit (totem);
 }
 
-void
-take_screenshot_action_callback (GtkAction *action, Totem *totem)
-{
-	totem_action_take_screenshot (totem);
-}
-
 void
 preferences_action_callback (GtkAction *action, Totem *totem)
 {
@@ -1005,6 +1064,13 @@ zoom_out_action_callback (GtkAction *action, Totem *totem)
 	totem_action_zoom_relative (totem, ZOOM_OUT_OFFSET);
 }
 
+void
+select_subtitle_action_callback (GtkAction *action, Totem *totem)
+{
+	totem_playlist_select_subtitle_dialog (totem->playlist,
+					       TOTEM_PLAYLIST_DIALOG_PLAYING);
+} 
+
 void
 next_angle_action_callback (GtkAction *action, Totem *totem)
 {
@@ -1087,7 +1153,6 @@ void
 about_action_callback (GtkAction *action, Totem *totem)
 {
 	char *backend_version, *description;
-	const char *frontend_type;
 
 	const char *authors[] =
 	{
@@ -1105,21 +1170,14 @@ about_action_callback (GtkAction *action, Totem *totem)
 	};
 	char *license = totem_interface_get_license ();
 
-#ifdef HAVE_GTK_ONLY
-	frontend_type = N_("GTK+");
-#else
-	frontend_type = N_("GNOME");
-#endif
-
 	backend_version = bacon_video_widget_get_backend_name (totem->bvw);
-	/* This lists the back-end and front-end types and versions, such as
-	 * Movie Player using GStreamer 0.10.1 and GNOME */
-	description = g_strdup_printf (_("Movie Player using %s and %s"),
-				       backend_version, _(frontend_type));
+	/* This lists the back-end type and version, such as
+	 * Movie Player using GStreamer 0.10.1 */
+	description = g_strdup_printf (_("Movie Player using %s"), backend_version);
 
 	gtk_show_about_dialog (GTK_WINDOW (totem->win),
 				     "version", VERSION,
-				     "copyright", _("Copyright \xc2\xa9 2002-2007 Bastien Nocera"),
+				     "copyright", _("Copyright \xc2\xa9 2002-2008 Bastien Nocera"),
 				     "comments", description,
 				     "authors", authors,
 				     "documenters", documenters,
@@ -1223,8 +1281,6 @@ show_controls_action_callback (GtkToggleAction *action, Totem *totem)
 
 	show = gtk_toggle_action_get_active (action);
 
-	g_message ("show_controls_action_callback %d", show);
-
 	/* Let's update our controls visibility */
 	if (show)
 		totem->controls_visibility = TOTEM_CONTROLS_VISIBLE;
@@ -1301,12 +1357,6 @@ totem_ui_manager_setup (Totem *totem)
 				G_N_ELEMENTS (seek_entries_rtl), totem);
 	}
 
-	/* Hide help if we're using GTK+ only */
-#ifdef HAVE_GTK_ONLY
-	GtkAction *action = gtk_action_group_get_action (totem->main_action_group, "contents");
-	gtk_action_set_visible (action, FALSE);
-#endif /* HAVE_GTK_ONLY */
-
 	totem->ui_manager = GTK_UI_MANAGER (gtk_builder_get_object (totem->xml, "totem-ui-manager"));
 
 	totem->devices_action_group = NULL;
