@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -30,7 +30,7 @@
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <gio/gio.h>
 
 #include "totem-playlist.h"
 #include "bacon-message-connection.h"
@@ -115,12 +115,15 @@ struct TotemObject {
 	/* Volume */
 	GtkWidget *volume;
 	gboolean volume_sensitive;
+	gboolean muted;
+	double prev_volume;
 
 	/* Subtitles/Languages menus */
 	GtkWidget *subtitles;
 	GtkWidget *languages;
 	GList *subtitles_list;
 	GList *language_list;
+	gboolean autoload_subs;
 
 	/* Fullscreen */
 	TotemFullscreen *fs;
@@ -137,7 +140,7 @@ struct TotemObject {
 	guint recent_ui_id;
 
 	/* Monitor for playlist unmounts and drives/volumes monitoring */
-	GnomeVFSVolumeMonitor *monitor;
+	GVolumeMonitor *monitor;
 	gboolean drives_changed;
 
 	/* session */
@@ -173,12 +176,18 @@ GtkWidget *totem_volume_create (void);
 void	totem_action_open			(Totem *totem);
 void	totem_action_open_location		(Totem *totem);
 void	totem_action_eject			(Totem *totem);
-void	totem_action_take_screenshot		(Totem *totem);
 void	totem_action_zoom_relative		(Totem *totem, int off_pct);
 void	totem_action_zoom_reset			(Totem *totem);
 void	totem_action_show_help			(Totem *totem);
 void	totem_action_show_properties		(Totem *totem);
+gboolean totem_action_open_files		(Totem *totem, char **list);
+G_GNUC_NORETURN void totem_action_error_and_exit (const char *title, const char *reason, Totem *totem);
 
 void	show_controls				(Totem *totem, gboolean was_fullscreen);
 
+char	*totem_setup_window			(Totem *totem);
+void	totem_callback_connect			(Totem *totem);
+void	playlist_widget_setup			(Totem *totem);
+void	video_widget_create			(Totem *totem);
+
 #endif /* __TOTEM_PRIVATE_H__ */
