@@ -31,6 +31,7 @@
 #include "totem-properties-view.h"
 
 #include "bacon-video-widget-properties.h"
+#include "bacon-video-widget.h"
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 
@@ -42,8 +43,6 @@ struct TotemPropertiesViewPriv {
 };
 
 static GObjectClass *parent_class = NULL;
-static void totem_properties_view_init (TotemPropertiesView *self);
-static void totem_properties_view_class_init (TotemPropertiesViewClass *class);
 static void totem_properties_view_finalize (GObject *object);
 
 G_DEFINE_TYPE (TotemPropertiesView, totem_properties_view, GTK_TYPE_TABLE)
@@ -96,7 +95,7 @@ on_got_metadata_event (BaconVideoWidget *bvw, TotemPropertiesView *props)
 	gtk_label_set_text (GTK_LABEL (props->priv->label), _(label));
 
 	bacon_video_widget_properties_update
-		(props->priv->props, props->priv->bvw);
+		(props->priv->props, GTK_WIDGET (props->priv->bvw));
 }
 
 static void
